LIMEPY 
========

Lowered Isothermal Model Explorer in PYthon
-------------------------------------------

.. .. image:: https://badge.fury.io/py/limepy.png
..     :target: http://badge.fury.io/py/limepy
..
.. .. image:: https://travis-ci.org/mgieles/limepy.png?branch=master
..         :target: https://travis-ci.org/mgieles/limepy
..
.. .. image:: https://pypip.in/d/limepy/badge.png
..         :target: https://pypi.python.org/pypi/limepy


Python environment for solving distribution function (DF) based
lowered isothermal models as described in Gieles & Zocchi 2015, MNRAS,
454, 576 (http://arxiv.org/abs/1508.02120)


Notebooks with example can be found in <https://github.com/mgieles/limepy/tree/master/notebooks>

Also check out LIMEPY within the browser with mybinder

   .. image:: http://mybinder.org/badge.svg 
        :target: http://mybinder.org/repo/mgieles/limepy


* Free software: BSD license
* Documentation: https://limepy.readthedocs.org. 

.. image:: https://readthedocs.org/projects/limepy/badge/?version=latest

:target: https://limepy.readthedocs.io/en/latest/?badge=latest
:alt: Documentation Status

Features
--------

* Solves Poisson's equation used on input parameters
* Fast solutions for isotropic/anisotropic, single/multi-mass models
* Normalised DF values
* Density and velocity moments
* Projected properties 
* Generate discrete samples
